@@ -29,10 +29,19 @@ class LRFinder(Callback):
             self.best_loss = batch_loss
         self.losses.append(batch_loss)
 
+    def on_train_epoch_end(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
+        trainer.should_stop = True
+        return super().on_train_epoch_end(trainer, pl_module)
+
+    def on_fit_end(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
+        self.plot()
+        return super().on_fit_end(trainer, pl_module)
+
     def plot(self):
         plt.plot(self.lrs, self.losses)
         plt.xlabel('learning rate')
         plt.ylabel('loss')
+        plt.show()
 
 
 class ModelAnalyzer(Callback):
