@@ -29,7 +29,7 @@ class ProgressMix:
         Returns:
             [int, int, int, int, dict]: current epoch, total epochs, current batch, total batchs, information dict
         """
-        info = trainer.progress_bar_dict
+        info = trainer.progress_bar_callback.get_metrics(trainer, trainer.task_module)
         info_dict = {self._key(k): v for k, v in info.items() if self._check_info(k, stage, unit)}
         if stage == 'train':
             c_batch = self.train_batch_id
@@ -78,7 +78,7 @@ class SimpleBar(ProgressBarBase, ProgressMix):
     def on_train_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
         self.train_batch_id = batch_idx + 1
         c_epoch, num_epoch, c_batch, num_batch, info_dict = self.get_info(trainer, 'train', 'step')
-        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4d}"
+        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4}"
         stage = 'TRAIN >'
         info = '  '.join([f'{k:>}: {v:0<6.4f}' for k, v in info_dict.items()])
         print(f"{progress} {stage} {info}", end="\r", flush=True)
@@ -88,17 +88,19 @@ class SimpleBar(ProgressBarBase, ProgressMix):
             trainer, 'train', 'epoch')
         val_c_epoch, val_num_epoch, val_c_batch, val_num_batch, val_info_dict = self.get_info(trainer, 'val', 'epoch')
 
-        progress = f"E:{train_c_epoch:>3d}/{train_num_epoch:<3d} B:{train_num_batch:>4d} {val_num_batch:<4d}"
+        progress = f"E:{train_c_epoch:>3d}/{train_num_epoch:<3d} B:{train_num_batch:>4} {val_num_batch:<4}"
         train_stage = 'TRAIN >'
         train_info = '  '.join([f'{k:>}: {v:0<6.4f}' for k, v in train_info_dict.items()])
         val_stage = '  VAL >'
         val_info = '  '.join([f'{k:>}: {v:0<6.4f}' for k, v in val_info_dict.items()])
+        if not val_info:
+            val_stage = ''
         print(progress, train_stage, train_info, val_stage, val_info)
 
     def on_validation_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
         self.val_batch_id = batch_idx + 1
         c_epoch, num_epoch, c_batch, num_batch, info_dict = self.get_info(trainer, 'val', 'step')
-        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4d}"
+        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4}"
         stage = '  VAL >'
         info = '  '.join([f'{k:>}: {v:0<6.4f}' for k, v in info_dict.items()])
         print(f"{progress} {stage} {info}", end="\r", flush=True)
@@ -109,14 +111,14 @@ class SimpleBar(ProgressBarBase, ProgressMix):
     def on_test_batch_end(self, trainer, pl_module, outputs, batch, batch_idx, dataloader_idx):
         self.test_batch_id = batch_idx + 1
         c_epoch, num_epoch, c_batch, num_batch, info_dict = self.get_info(trainer, 'test', 'step')
-        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4d}"
+        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4}"
         stage = ' TEST >'
         info = '  '.join([f'{k:>}: {v:0<6.4f}' for k, v in info_dict.items()])
         print(f"{progress} {stage} {info}", end="\r", flush=True)
 
     def on_test_epoch_end(self, trainer, pl_module):
         c_epoch, num_epoch, c_batch, num_batch, info_dict = self.get_info(trainer, 'test', 'epoch')
-        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4d}"
+        progress = f"E:{c_epoch:>3d}/{num_epoch:<3d} B:{c_batch:>4d}/{num_batch:<4}"
         stage = ' TEST >'
         info = '  '.join([f'{k:>}: {v:0<6.4f}' for k, v in info_dict.items()])
         print(progress, stage, info)
@@ -179,7 +181,7 @@ class Progress(Callback, ProgressMix):
                 for metric in metrics
             }
             val_info = {
-                metric: [e['val_epoch'][metric] for e in self.progress_info]
+                metric: [e['val_epoch'][metric] for e in self.progress_info if e['val_epoch']]
                 for metric in metrics
             }
             trainer.progress = {'train': train_info, 'val': val_info}
@@ -190,7 +192,7 @@ class Progress(Callback, ProgressMix):
                 for metric in metrics
             }
             val_info = {
-                metric: list(chain.from_iterable([[b[metric] for b in e['val_epoch']] for e in self.progress_info]))
+                metric: list(chain.from_iterable([[b[metric] for b in e['val_epoch']] for e in self.progress_info if e['val_epoch']]))
                 for metric in metrics
             }
             trainer.progress = {'train': train_info, 'val': val_info}
\ No newline at end of file
